<?PHP // $Id$ 
      // journal.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['alwaysopen'] = '׻ ';
$string['blankentry'] = '鿡 ';
$string['daysavailable'] = ' ̿밡';
$string['editingended'] = ' Ⱓ Ϸ';
$string['editingends'] = ' Ⱓ Ϸ';
$string['entries'] = '';
$string['feedbackupdated'] = '    (ǰ)';
$string['journalmail'] = '簡 츮 ο  ǰ ؿԴ. 
  ο ÷Ȱ   ֽϴ.';
$string['journalmailhtml'] = '簡 츮 ο  ǰ ؿԴ. 
  ο ÷Ȱ   ֽϴ.';
$string['journalname'] = ' Ī';
$string['journalquestion'] = ' ǹ';
$string['journalrating1'] = 'ϴ,ʴ';
$string['journalrating2'] = '';
$string['journalrating3'] = 'ϴ,پ';
$string['modulename'] = '';
$string['modulenameplural'] = '';
$string['newjournalentries'] = 'α';
$string['noentry'] = '';
$string['noratinggiven'] = '򰡹̿Ϸ(򰡸  ʾҴ';
$string['notopenuntil'] = '   ϱ  ʰڽϴ';
$string['notstarted'] = '     ʾҽϴ';
$string['overallrating'] = 'ü ()';
$string['rate'] = 'ϴ, ';
$string['saveallfeedback'] = '  ǰ ض(ض)';
$string['startoredit'] = ' α縦  Ǵ մϴ.';
$string['thischarset'] = 'euc-kr';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = '&#54620;&#44397;&#50612;';
$string['viewallentries'] = ' ٽ ';

?>
